@@ -2,6 +2,6 @@
 #
 # SPDX-License-Identifier: MIT
 CLI_NAME = 'sigopt'
-CONTROLLER_IMAGE_VERSION = "2021-10-11a"
-CONTROLLER_REPOSITORY = "sigopt/controller"
+CONTROLLER_IMAGE_VERSION = "2022-11-09a"
+CONTROLLER_REPOSITORY = "intel/sigopt-controller"
 DEFAULT_CONTROLLER_IMAGE = f"{CONTROLLER_REPOSITORY}:{CONTROLLER_IMAGE_VERSION}"
